# BRASS: Build Release Assembler for Sane Software

There's only one [file](brass/brass.py).

The docs live here: https://biosafetylvl5.github.io/brass/

## Install

``` bash
pip3 install git+https://github.com/biosafetylvl5/brass.git
```

or

``` bash
pip install git+https://github.com/biosafetylvl5/brass.git
```
